package com.company.demo.security;


import jakarta.servlet.FilterChain;
import jakarta.servlet.ServletException;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.stereotype.Component;
import org.springframework.web.filter.OncePerRequestFilter;

import java.io.IOException;
import java.security.SecureRandom;
import java.util.Base64;

@Component
public class HttpMethodFilter extends OncePerRequestFilter {

    private static final SecureRandom secureRandom = new SecureRandom();
    private static final Base64.Encoder base64Encoder = Base64.getUrlEncoder();

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain)
            throws ServletException, IOException {


        byte[] nonceBytes = new byte[16];
        secureRandom.nextBytes(nonceBytes);
        String nonce = base64Encoder.encodeToString(nonceBytes);

        // Set the nonce in the response header
        ((HttpServletResponse) response).setHeader("Content-Security-Policy", "base-uri 'self'; default-src 'self'; connect-src 'self' https://microloanappuat.kgroupuat.com:8443/KML-MLOS-2-Phase2-Appsec-Header/login-new-view; img-src 'self' data:;style-src 'self' 'unsafe-inline'; script-src 'self' 'unsafe-eval' 'nonce-" + nonce + "'; font-src 'self' data:;");

        ((HttpServletResponse) response).setHeader("X-XSS-Protection", "1; mode=block");
        ((HttpServletResponse) response).setHeader("Cache-Control",
                "no-store, no-cache, must-revalidate, max-age=0, post-check=0, pre-check=0");
        ((HttpServletResponse) response).setHeader("Pragma", "no-cache");
        ((HttpServletResponse) response).setHeader("Strict-Transport-Security", "max-age=31536000; includeSubDomains; preload");
        ((HttpServletResponse) response).setHeader("Referrer-Policy", "no-referrer");
        // Pass the nonce to the request attributes for use in HTML
        request.setAttribute("cspNonce", nonce);


        String method = request.getMethod();
        //if (method.equals("OPTIONS") || method.equals("PUT") || method.equals("DELETE") || method.equals("PATCH") || method.equals("HEAD")) {
        if (method.equals("GET") || method.equals("POST")) {
            filterChain.doFilter(request, response);
        } else {
            response.sendError(HttpServletResponse.SC_METHOD_NOT_ALLOWED);
        }
    }
}



