package com.company.demo.security;

import com.vaadin.flow.server.VaadinServiceInitListener;
import com.vaadin.flow.server.VaadinSession;
import com.vaadin.flow.server.communication.IndexHtmlResponse;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import java.security.SecureRandom;
import java.util.Base64;

@Configuration
public class NonceDemoConfiguration {

    private static final SecureRandom secureRandom = new SecureRandom();
    private static final Base64.Encoder base64Encoder = Base64.getUrlEncoder();

    public static final String NONCE_ATTRIBUTE = "csp-nonce";

    @Bean
    public VaadinServiceInitListener cspNonceInjector() {
        return initEvent -> initEvent.addIndexHtmlRequestListener(this::injectCspNonce);
    }

    private void injectCspNonce(IndexHtmlResponse response) {
        // Use CSP only in production mode
        if (!response.getVaadinRequest().getService().getDeploymentConfiguration().isProductionMode()) {
            return;
        }

        byte[] nonceBytes = new byte[16];
        secureRandom.nextBytes(nonceBytes);
        String nonce = base64Encoder.encodeToString(nonceBytes);
        VaadinSession.getCurrent().setAttribute(NONCE_ATTRIBUTE, nonce);

        // Add a header to make the browser require the nonce in all script tags
        response.getVaadinResponse().setHeader("Content-Security-Policy",
                "script-src 'nonce-" + nonce + "' 'unsafe-eval'");

        // Add the nonce to all script tags in the host page
        response.getDocument().getElementsByTag("script").attr("nonce", nonce);
    }
}